@@ -65,7 +65,7 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
             value_array.append(None)
             continue
 
-        if dtype == "LONG":
+        if dtype == "LONG" or dtype == "DATE":
             value_array.append(dis.read_long())
         elif dtype == "STRING":
             value_array.append(dis.read_utf().decode())
@@ -87,7 +87,7 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
             value_array.append(dis.read_byte())
         elif dtype == "INT96":
             value_array.append(dis.read_utf())
-        elif dtype == "INTEGER" or dtype == "DATE":
+        elif dtype == "INTEGER":
             value_array.append(dis.read_int())
 
     return value_array
