@@ -10,10 +10,12 @@ import datetime
 # Make all exceptions visible in this e6xdb per DB-API
 import logging
 import re
+import socket
 import sys
 from decimal import Decimal
 from io import BytesIO
 from ssl import CERT_NONE, CERT_OPTIONAL, CERT_REQUIRED
+from urllib.parse import urlparse
 
 from thrift.protocol import TBinaryProtocol, TMultiplexedProtocol
 from thrift.transport import TSocket
@@ -22,7 +24,7 @@ from thrift.transport import TTransport
 from e6xdb import common
 from e6xdb.common import DBAPITypeObject
 from e6xdb.constants import *
-from e6xdb.datainputstream import DataInputStream, get_query_columns_info, read_rows_from_batch
+from e6xdb.datainputstream import DataInputStream, read_values_from_array, get_query_columns_info, read_rows_from_batch
 from e6xdb.server import QueryEngine
 from e6xdb.typeId import *
 
@@ -157,7 +159,7 @@ class Connection(object):
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         """Call close"""
-        self.close(self)
+        self.close()
 
     def close(self, query_id):
         self._client.clear(query_id)
@@ -183,6 +185,11 @@ class Connection(object):
         return self._client
 
 
+"""
+Reading from Java DataInputStream format.
+"""
+
+
 class Cursor(common.DBAPICursor):
     """These objects represent a database cursor, which is used to manage the context of a fetch
     operation.
@@ -305,7 +312,7 @@ class Cursor(common.DBAPICursor):
         return self._data
 
     def fetch_batch(self):
-        _logger.debug("fetching next batch from e6data")
+        _logger.info("fetching next batch from e6data")
         client = self.connection.client
         buffer = client.getNextResultBatch(self._query_id)
 
@@ -322,6 +329,7 @@ class Cursor(common.DBAPICursor):
         return self._fetch_all()
 
     def fetchone(self):
+        _logger.info("fetching one")
         if len(self._batch) == 0:
             self.fetch_batch()
             if len(self._batch) == 0:
